import type { CreateTenantOptions, GetTenantAgentOptions, WithTenantAgentCallback } from './TenantsApiOptions';
import type { TenantRecord } from './repository';
import type { DefaultAgentModules, ModulesMap, Query } from '@credo-ts/core';
import { AgentContext, AgentContextProvider, Logger } from '@credo-ts/core';
import { TenantAgent } from './TenantAgent';
import { TenantRecordService } from './services';
export declare class TenantsApi<AgentModules extends ModulesMap = DefaultAgentModules> {
    readonly rootAgentContext: AgentContext;
    private tenantRecordService;
    private agentContextProvider;
    private logger;
    constructor(tenantRecordService: TenantRecordService, rootAgentContext: AgentContext, agentContextProvider: AgentContextProvider, logger: Logger);
    getTenantAgent({ tenantId }: GetTenantAgentOptions): Promise<TenantAgent<AgentModules>>;
    withTenantAgent(options: GetTenantAgentOptions, withTenantAgentCallback: WithTenantAgentCallback<AgentModules>): Promise<void>;
    createTenant(options: CreateTenantOptions): Promise<TenantRecord>;
    getTenantById(tenantId: string): Promise<TenantRecord>;
    deleteTenantById(tenantId: string): Promise<void>;
    updateTenant(tenant: TenantRecord): Promise<void>;
    findTenantsByQuery(query: Query<TenantRecord>): Promise<TenantRecord[]>;
    getAllTenants(): Promise<TenantRecord[]>;
}
